@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.message.server;
 
 import java.io.IOException;
@@ -84,10 +84,10 @@ public class PrepareResultPacket implements Completion, Prepare {
         // skipping packet, since there is no metadata information.
         // might change when https://jira.mariadb.org/browse/MDEV-15031 is done
         parameters[i] = CONSTANT_PARAMETER;
-        reader.skipPacket();
+        reader.readReusablePacket();
       }
       if (!context.isEofDeprecated()) {
-        reader.skipPacket();
+        reader.readReusablePacket();
       }
     }
     if (numColumns > 0) {
@@ -98,7 +98,7 @@ public class PrepareResultPacket implements Completion, Prepare {
                 .apply(new StandardReadableByteBuf(reader.readPacket(trace)));
       }
       if (!context.isEofDeprecated()) {
-        reader.skipPacket();
+        reader.readReusablePacket();
       }
     }
   }
